@@ -4,7 +4,6 @@
 """Simple test for 16x2 character lcd connected to an MCP23008 I2C LCD backpack."""
 import time
 import board
-import busio
 import adafruit_character_lcd.character_lcd_i2c as character_lcd
 
 # Modify this if you have a different sized Character LCD
@@ -12,7 +11,7 @@ lcd_columns = 16
 lcd_rows = 2
 
 # Initialise I2C bus.
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
 
 # Initialise the lcd class
 lcd = character_lcd.Character_LCD_I2C(i2c, lcd_columns, lcd_rows)
